Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8)

Unified Diff: gclient.py

Issue 10116033: Avoid parallel sync in general on arm boards. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/depot_tools/
Patch Set: Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: gclient.py
===================================================================
--- gclient.py (revision 132856)
+++ gclient.py (working copy)
@@ -55,12 +55,13 @@
import logging
import optparse
import os
+import platform
import posixpath
import pprint
import re
import sys
+import urllib
import urlparse
-import urllib
import breakpad # pylint: disable=W0611
@@ -1498,8 +1499,11 @@
def Parser():
"""Returns the default parser."""
parser = optparse.OptionParser(version='%prog ' + __version__)
- # cygwin has issues with parallel sync
- jobs = 1 if sys.platform == 'cygwin' else 8
+ # cygwin and some arm boards have issues with parallel sync.
+ if sys.platform == 'cygwin' or platform.machine().startswith('arm'):
+ jobs = 1
+ else:
+ jobs = 8
parser.add_option('-j', '--jobs', default=jobs, type='int',
help='Specify how many SCM commands can run in parallel; '
'default=%default')
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698